# dadapush-client
DaDaPush: Real-time Notifications App Send real-time notifications through our API without coding and maintaining your own app for iOS or Android devices.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v1
- Package version: 1.0.1
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://www.dadapush.com](https://www.dadapush.com)

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import dadapush_client 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import dadapush_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import dadapush_client
from dadapush_client.rest import ApiException
from pprint import pprint


# create an instance of the API class
api_instance = dadapush_client.DaDaPushMessageApi(dadapush_client.ApiClient(configuration))
body = dadapush_client.MessagePushRequest() # MessagePushRequest | body
x_channel_token = 'x_channel_token_example' # str | see: https://www.dadapush.com/channel/list (optional)

try:
    # push Message to a Channel
    api_response = api_instance.create_message(body, x_channel_token=x_channel_token)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling DaDaPushMessageApi->create_message: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://www.dadapush.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DaDaPushMessageApi* | [**create_message**](docs/DaDaPushMessageApi.md#create_message) | **POST** /api/v1/message | push Message to a Channel
*DaDaPushMessageApi* | [**delete_message**](docs/DaDaPushMessageApi.md#delete_message) | **DELETE** /api/v1/message/{messageId} | delete a Channel Message
*DaDaPushMessageApi* | [**get_message**](docs/DaDaPushMessageApi.md#get_message) | **GET** /api/v1/message/{messageId} | get a Channel Message
*DaDaPushMessageApi* | [**get_messages**](docs/DaDaPushMessageApi.md#get_messages) | **GET** /api/v1/messages | get Message List


## Documentation For Models

 - [Action](docs/Action.md)
 - [MessageObject](docs/MessageObject.md)
 - [MessagePushRequest](docs/MessagePushRequest.md)
 - [MessagePushResponse](docs/MessagePushResponse.md)
 - [PageResponseOfMessageObject](docs/PageResponseOfMessageObject.md)
 - [Result](docs/Result.md)
 - [ResultOfMessageObject](docs/ResultOfMessageObject.md)
 - [ResultOfMessagePushResponse](docs/ResultOfMessagePushResponse.md)
 - [ResultOfPageResponseOfMessageObject](docs/ResultOfPageResponseOfMessageObject.md)


## Documentation For Authorization

 All endpoints do not require authorization.

## Author

contacts@dadapush.com


